hypervisor

package
v0.0.0-...-80cfa99 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2017 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DetectVBoxManageCmd

func DetectVBoxManageCmd() (string, bool)

func InstallVirtualBox

func InstallVirtualBox(fail bool) error

InstallVirtualBox Perform a VirtualBox install

func InstallXhyve

func InstallXhyve(fail bool) error

InstallXhyve Perform a xhyve install Will elevate by default

func SelectAndPrepareHypervisor

func SelectAndPrepareHypervisor(preferred string) string

SelectAndPrepareHypervisor Select the preferred hypervisor for the platform, and prepare it if necessary

Types

This section is empty.

Jump to