version

package
v0.0.0-...-80cfa99 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2017 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const VersionPrefix = "v"

The current version of the minikube and localkube This is a private field and should be set when compiling with --ldflags="-X github.com/stackfoundation/sandbox/core/pkg/version.version=vX.Y.Z"

Variables

This section is empty.

Functions

func GetIsoPath

func GetIsoPath() string

func GetIsoVersion

func GetIsoVersion() string

func GetSemverVersion

func GetSemverVersion() (semver.Version, error)

func GetVersion

func GetVersion() string

Types

This section is empty.

Jump to