Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StepContext ¶
type StepContext struct {
WorkflowContext *WorkflowContext
Change *v1.Change
NextStep *v1.WorkflowStep
NextStepSelector []int
Step *v1.WorkflowStep
StepSelector []int
}
StepContext Context for a step execution
func NewStepContext ¶
func NewStepContext(wc *WorkflowContext, c *v1.Change) *StepContext
NewStepContext Create a new step execution context
func (*StepContext) CanProceedToNextStep ¶
func (sc *StepContext) CanProceedToNextStep() bool
CanProceedToNextStep Can we move on to the next step in context?
func (*StepContext) IsCompoundStepComplete ¶
func (sc *StepContext) IsCompoundStepComplete() bool
IsCompoundStepComplete Is the current step in context a compound step that's complete?
func (*StepContext) IsGeneratedWorkflowReadyToRun ¶
func (sc *StepContext) IsGeneratedWorkflowReadyToRun() bool
IsGeneratedWorkflowReadyToRun Is the current generated workflow step in context ready to run?
func (*StepContext) IsStepReadyToRun ¶
func (sc *StepContext) IsStepReadyToRun() bool
IsStepReadyToRun Is the current step in context ready to run?
func (*StepContext) IsWorkflowComplete ¶
func (sc *StepContext) IsWorkflowComplete() bool
IsWorkflowComplete Is the workflow in context complete?
type WorkflowContext ¶
type WorkflowContext struct {
Cancel func()
Cleanup *sync.WaitGroup
Context context.Context
Workflow *v1.Workflow
}
WorkflowContext Context for a workflow execution
func NewWorkflowContext ¶
func NewWorkflowContext(context context.Context, cancel func(), cleanup *sync.WaitGroup, workflow *v1.Workflow) *WorkflowContext
NewWorkflowContext Create a new workflow execution context
Click to show internal directories.
Click to hide internal directories.