metadata

package
v0.0.0-...-80cfa99 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2017 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SaveMetadata

func SaveMetadata(metadata *Metadata) error

SaveMetadata Save the given metadata in the standard location

Types

type Metadata

type Metadata struct {
	Description string    `json:"description"`
	Bootstrap   Version   `json:"bootstrap"`
	Core        Version   `json:"core"`
	Checked     time.Time `json:"checked"`
	Driver      string    `json:"driver"`
	VirtualBox  string    `json:"virtualBox"`
}

Metadata CLI metadata

func GetMetadata

func GetMetadata() (*Metadata, error)

GetMetadata Get the metadata from the standard location, if any exists

func WithVersions

func WithVersions(bootstrapVersion Version, coreVersion Version) *Metadata

WithVersions Create new metadata with the specified bootstrap and core component versions

func (*Metadata) NeedsUpdate

func (metadata *Metadata) NeedsUpdate() bool

NeedsUpdate Does the specified metadata need to be updated?

type Version

type Version struct {
	Version  string `json:"version"`
	Updated  string `json:"updated"`
	Checksum string `json:"checksum"`
	Local    string `json:"local"`
	Remote   string `json:"remote"`
}

Version Version of CLI component

Jump to