process

package
v0.0.0-...-80cfa99 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2017 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CombineStdStreams

func CombineStdStreams(command string, args ...string) error

CombineStdStreams Execute a process, wait till completion, and combine std streams to this process

func CommandOut

func CommandOut(command string, args ...string) (string, error)

CommandOut Execute a process, wait till completion, and return the stdout

func CommandWithoutOut

func CommandWithoutOut(command string, args ...string) error

CommandWithoutOut Execute a process, wait till completion, and don't ouput process's streams

Types

This section is empty.

Jump to