Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DetectVBoxManageCmd ¶
func InstallVirtualBox ¶
InstallVirtualBox Perform a VirtualBox install
func InstallXhyve ¶
InstallXhyve Perform a xhyve install Will elevate by default
func SelectAndPrepareHypervisor ¶
SelectAndPrepareHypervisor Select the preferred hypervisor for the platform, and prepare it if necessary
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.