Documentation
¶
Index ¶
- Constants
- func CanReadFile(path string) bool
- func ChownR(path string, uid, gid int) error
- func FindAndSet(path string, c interface{}, value string) error
- func GenerateCACert(certPath, keyPath string, name string) error
- func GenerateSignedCert(certPath, keyPath string, ips []net.IP, alternateDNS []string, ...) error
- func GetAlternateDNS(domain string) []string
- func GetLocalkubeDownloadURL(versionOrURL string, filename string) (string, error)
- func IsDirectory(path string) (bool, error)
- func MaybeChownDirRecursiveToMinikubeUser(dir string) error
- func Pad(str string) string
- func ParseSHAFromURL(url string) (string, error)
- func Retry(attempts int, callback func() error) (err error)
- func RetryAfter(attempts int, callback func() error, d time.Duration) (err error)
- func Until(fn func() error, w io.Writer, name string, sleep time.Duration, ...)
- type DefaultDownloader
- func (f DefaultDownloader) CacheMinikubeISOFromURL(isoURL string) error
- func (f DefaultDownloader) GetISOCacheFilepath(isoURL string) string
- func (f DefaultDownloader) GetISOFileURI(isoURL string) string
- func (f DefaultDownloader) IsMinikubeISOCached(isoURL string) bool
- func (f DefaultDownloader) ShouldCacheMinikubeISO(isoURL string) bool
- type ExtraOption
- type ExtraOptionSlice
- type ISODownloader
- type MultiError
- type RetriableError
Constants ¶
const ( APIServerPort = 8443 DefaultLocalkubeDirectory = "/var/lib/localkube" DefaultCertPath = DefaultLocalkubeDirectory + "/certs/" DefaultKubeConfigPath = DefaultLocalkubeDirectory + "/kubeconfig" DefaultServiceClusterIP = "10.0.0.1" DefaultDNSDomain = "cluster.local" DefaultDNSIP = "10.0.0.10" DefaultInsecureRegistry = "10.0.0.0/24" )
These constants are used by both minikube and localkube
Variables ¶
This section is empty.
Functions ¶
func CanReadFile ¶
If the file represented by path exists and readable, return true otherwise return false.
func FindAndSet ¶
FindAndSet sets the nested value.
func GenerateCACert ¶
func GenerateSignedCert ¶
func GenerateSignedCert(certPath, keyPath string, ips []net.IP, alternateDNS []string, signerCertPath, signerKeyPath string) error
You may also specify additional subject alt names (either ip or dns names) for the certificate The certificate will be created with file mode 0644. The key will be created with file mode 0600. If the certificate or key files already exist, they will be overwritten. Any parent directories of the certPath or keyPath will be created as needed with file mode 0755.
func GetAlternateDNS ¶
func GetLocalkubeDownloadURL ¶
func IsDirectory ¶
func ParseSHAFromURL ¶
Types ¶
type DefaultDownloader ¶
type DefaultDownloader struct{}
func (DefaultDownloader) CacheMinikubeISOFromURL ¶
func (f DefaultDownloader) CacheMinikubeISOFromURL(isoURL string) error
func (DefaultDownloader) GetISOCacheFilepath ¶
func (f DefaultDownloader) GetISOCacheFilepath(isoURL string) string
func (DefaultDownloader) GetISOFileURI ¶
func (f DefaultDownloader) GetISOFileURI(isoURL string) string
func (DefaultDownloader) IsMinikubeISOCached ¶
func (f DefaultDownloader) IsMinikubeISOCached(isoURL string) bool
func (DefaultDownloader) ShouldCacheMinikubeISO ¶
func (f DefaultDownloader) ShouldCacheMinikubeISO(isoURL string) bool
type ExtraOption ¶
func (*ExtraOption) String ¶
func (e *ExtraOption) String() string
type ExtraOptionSlice ¶
type ExtraOptionSlice []ExtraOption
func (*ExtraOptionSlice) Set ¶
func (es *ExtraOptionSlice) Set(value string) error
func (*ExtraOptionSlice) String ¶
func (es *ExtraOptionSlice) String() string
func (*ExtraOptionSlice) Type ¶
func (es *ExtraOptionSlice) Type() string
type ISODownloader ¶
type MultiError ¶
type MultiError struct {
Errors []error
}
func (*MultiError) Collect ¶
func (m *MultiError) Collect(err error)
func (MultiError) ToError ¶
func (m MultiError) ToError() error
type RetriableError ¶
type RetriableError struct {
Err error
}
func (RetriableError) Error ¶
func (r RetriableError) Error() string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.