Documentation
¶
Index ¶
Constants ¶
const VersionPrefix = "v"
The current version of the minikube and localkube This is a private field and should be set when compiling with --ldflags="-X github.com/stackfoundation/sandbox/core/pkg/version.version=vX.Y.Z"
Variables ¶
This section is empty.
Functions ¶
func GetIsoPath ¶
func GetIsoPath() string
func GetIsoVersion ¶
func GetIsoVersion() string
func GetSemverVersion ¶
func GetVersion ¶
func GetVersion() string
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.