Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SaveMetadata ¶
SaveMetadata Save the given metadata in the standard location
Types ¶
type Metadata ¶
type Metadata struct {
Description string `json:"description"`
Bootstrap Version `json:"bootstrap"`
Core Version `json:"core"`
Checked time.Time `json:"checked"`
Driver string `json:"driver"`
VirtualBox string `json:"virtualBox"`
}
Metadata CLI metadata
func GetMetadata ¶
GetMetadata Get the metadata from the standard location, if any exists
func WithVersions ¶
WithVersions Create new metadata with the specified bootstrap and core component versions
func (*Metadata) NeedsUpdate ¶
NeedsUpdate Does the specified metadata need to be updated?
Click to show internal directories.
Click to hide internal directories.