Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CombineStdStreams ¶
CombineStdStreams Execute a process, wait till completion, and combine std streams to this process
func CommandOut ¶
CommandOut Execute a process, wait till completion, and return the stdout
func CommandWithoutOut ¶
CommandWithoutOut Execute a process, wait till completion, and don't ouput process's streams
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.